@@ -16,15 +16,21 @@ GET_NAME=$(dirname "$0")/get_name.py
 
 NAME=$($GET_NAME "$INI")
 
+# ensure output directory exists
+mkdir -p "$(dirname "$EET_FILE")"
+
 # generate desc on a temporary file
 TMP_DESC=$(mktemp "$NAME-DESC-XXXXXX")
+TMP_EET=$(mktemp "$NAME-EET-XXXXXX")
 
 # trap to avoid creating orphan files
-trap 'rm -f "$TMP_DESC"' INT TERM HUP EXIT
+trap 'rm -f "$TMP_DESC" "$TMP_EET"' INT TERM HUP EXIT
+
+NAME=$($GET_NAME "$INI")
 
 [ ! -w "$EET_FILE" ] && touch "$EET_FILE"
 
-NAME=$($GET_NAME "$INI")
+echo "Generating $EET_FILE"
 
 $INI2DESC "$INI" "$TMP_DESC"
 $EET -e "$EET_FILE" "$NAME" "$TMP_DESC" "$COMPRESS"
