@@ -1,7 +1,7 @@
 #ifndef _ABOUT_H__
 #define _ABOUT_H__ 1
 
-void about_toggle(Evas_Object *win, Evas_Object *bg, Evas_Object *term,
+void about_show(Evas_Object *win, Evas_Object *base, Evas_Object *term,
                   void (*donecb) (void *data), void *donedata);
 
 #endif
