@@ -4,10 +4,10 @@
 #include <Efreet.h>
 #include "config.h"
 #include "main.h"
-#include "col.h"
+#include "colors.h"
 #include "theme.h"
 
-#define CONF_VER 25
+#define CONF_VER 26
 #define CONFIG_KEY "config"
 
 #define LIM(v, min, max) {if (v >= max) v = max; else if (v <= min) v = min;}
@@ -36,22 +36,19 @@ config_init(void)
             _config_home_get());
    ecore_file_mkpath(path);
 
-   eet_eina_stream_data_descriptor_class_set
-     (&eddc, sizeof(eddc), "Config", sizeof(Config));
-   edd_base = eet_data_descriptor_stream_new(&eddc);
 
    eet_eina_stream_data_descriptor_class_set
-     (&eddc, sizeof(eddc), "Config_Color", sizeof(Config_Color));
+     (&eddc, sizeof(eddc), "Config_Color", sizeof(Color));
    edd_color = eet_data_descriptor_stream_new(&eddc);
 
    EET_DATA_DESCRIPTOR_ADD_BASIC
-     (edd_color, Config_Color, "r", r, EET_T_UCHAR);
+     (edd_color, Color, "r", r, EET_T_UCHAR);
    EET_DATA_DESCRIPTOR_ADD_BASIC
-     (edd_color, Config_Color, "g", g, EET_T_UCHAR);
+     (edd_color, Color, "g", g, EET_T_UCHAR);
    EET_DATA_DESCRIPTOR_ADD_BASIC
-     (edd_color, Config_Color, "b", b, EET_T_UCHAR);
+     (edd_color, Color, "b", b, EET_T_UCHAR);
    EET_DATA_DESCRIPTOR_ADD_BASIC
-     (edd_color, Config_Color, "a", a, EET_T_UCHAR);
+     (edd_color, Color, "a", a, EET_T_UCHAR);
 
 
    eet_eina_stream_data_descriptor_class_set
@@ -75,6 +72,11 @@ config_init(void)
    EET_DATA_DESCRIPTOR_ADD_BASIC
      (edd_keys, Config_Keys, "cb", cb, EET_T_STRING);
 
+
+   eet_eina_stream_data_descriptor_class_set
+     (&eddc, sizeof(eddc), "Config", sizeof(Config));
+   edd_base = eet_data_descriptor_stream_new(&eddc);
+
    EET_DATA_DESCRIPTOR_ADD_BASIC
      (edd_base, Config, "version", version, EET_T_INT);
    EET_DATA_DESCRIPTOR_ADD_BASIC
@@ -103,6 +105,8 @@ config_init(void)
      (edd_base, Config, "helper.inline_please", helper.inline_please, EET_T_UCHAR);
    EET_DATA_DESCRIPTOR_ADD_BASIC
      (edd_base, Config, "theme", theme, EET_T_STRING);
+   EET_DATA_DESCRIPTOR_ADD_BASIC
+     (edd_base, Config, "color_scheme_name", color_scheme_name, EET_T_STRING);
    EET_DATA_DESCRIPTOR_ADD_BASIC
      (edd_base, Config, "background", background, EET_T_STRING);
    EET_DATA_DESCRIPTOR_ADD_BASIC
@@ -200,16 +204,12 @@ config_init(void)
 void
 config_shutdown(void)
 {
-   if (edd_base)
-     {
-        eet_data_descriptor_free(edd_base);
-        edd_base = NULL;
-     }
-   if (edd_color)
-     {
-        eet_data_descriptor_free(edd_color);
-        edd_color = NULL;
-     }
+   eet_data_descriptor_free(edd_base);
+   edd_base = NULL;
+
+   eet_data_descriptor_free(edd_color);
+   edd_color = NULL;
+
    efreet_shutdown();
 }
 
@@ -284,6 +284,7 @@ config_sync(const Config *config_src, Config *config)
    eina_stringshare_replace(&(config->helper.local.video), config_src->helper.local.video);
    eina_stringshare_replace(&(config->helper.local.image), config_src->helper.local.image);
    eina_stringshare_replace(&(config->theme), config_src->theme);
+   eina_stringshare_replace(&(config->color_scheme_name), config_src->color_scheme_name);
    config->scrollback = config_src->scrollback;
    config->tab_zoom = config_src->tab_zoom;
    config->hide_cursor = config_src->hide_cursor;
@@ -550,6 +551,7 @@ config_new(void)
         config->helper.inline_please = EINA_TRUE;
         config->scrollback = 2000;
         config->theme = eina_stringshare_add("default.edj");
+        config->color_scheme_name = eina_stringshare_add("Default");
         config->background = NULL;
         config->tab_zoom = 0.5;
         config->opacity = 50;
@@ -572,7 +574,7 @@ config_new(void)
         config->visualize = EINA_TRUE;
         config->urg_bell = EINA_TRUE;
         config->multi_instance = EINA_FALSE;
-        config->xterm_256color = EINA_FALSE;
+        config->xterm_256color = EINA_TRUE;
         config->erase_is_del = EINA_FALSE;
         config->custom_geometry = EINA_FALSE;
         config->drag_links = EINA_FALSE;
@@ -603,11 +605,11 @@ config_new(void)
         config->shine = 255;
         config->hide_cursor = 5.0;
         config->group_all = EINA_FALSE;
+        config_compute_color_scheme(config);
      }
    return config;
 }
 
-
 Config *
 config_load(void)
 {
@@ -748,7 +750,35 @@ config_load(void)
                      config->active_links_escape);
                   EINA_FALLTHROUGH;
                   /*pass through*/
-                case CONF_VER: /* 25 */
+                case 25:
+                  #define THEME_TO_COLORSCHEME(_Theme, _Base, _ColorSheme)   \
+                  do {                                                       \
+                       if (!strncmp(config->theme, _Theme, sizeof(_Theme)-1)) \
+                         {                                                   \
+                            eina_stringshare_replace(&config->theme,         \
+                                                     _Base);                 \
+                            eina_stringshare_replace(                        \
+                               &config->color_scheme_name,                   \
+                               _ColorSheme);                                 \
+                         }                                                   \
+                  } while (0)
+
+                  THEME_TO_COLORSCHEME("mild.edj", "mild.edj", "Mild");
+                  THEME_TO_COLORSCHEME("black.edj", "mild.edj", "Black");
+                  THEME_TO_COLORSCHEME("solarized.edj", "default.edj", "Solarized");
+                  THEME_TO_COLORSCHEME("solarized_light.edj", "default.edj", "Solarized Light");
+                  THEME_TO_COLORSCHEME("mustang.edj", "mild.edj", "Mustang");
+                  THEME_TO_COLORSCHEME("base16_ocean_dark.edj", "mild.edj", "Ocean Dark");
+                  THEME_TO_COLORSCHEME("smyck.edj", "mild.edj", "Smyck");
+                  THEME_TO_COLORSCHEME("nord.edj", "default.edj", "Nord");
+                  THEME_TO_COLORSCHEME("papercolor.edj", "default.edj", "PaperColor");
+
+                  #undef THEME_TO_COLORSCHEME
+
+                  config_compute_color_scheme(config);
+                  EINA_FALLTHROUGH;
+                  /*pass through*/
+                case CONF_VER: /* 26 */
                   config->version = CONF_VER;
                   break;
                 default:
@@ -771,6 +801,7 @@ config_load(void)
      }
    else
      {
+        config_compute_color_scheme(config);
         config->font_set = 1;
      }
 
@@ -811,6 +842,8 @@ config_fork(const Config *config)
    SCPY(helper.local.image);
    CPY(helper.inline_please);
    SCPY(theme);
+   SCPY(color_scheme_name);
+   config2->color_scheme = color_scheme_dup(config->color_scheme);
    SCPY(background);
    CPY(scrollback);
    CPY(tab_zoom);
@@ -882,6 +915,8 @@ config_del(Config *config)
    eina_stringshare_del(config->font.name);
    eina_stringshare_del(config->font.orig_name);
    eina_stringshare_del(config->theme);
+   eina_stringshare_del(config->color_scheme_name);
+   free((void*)config->color_scheme);
    eina_stringshare_del(config->background);
    eina_stringshare_del(config->helper.email);
    eina_stringshare_del(config->helper.url.general);
