@@ -5,7 +5,7 @@
 #include <assert.h>
 #include <math.h>
 
-#include "col.h"
+#include "colors.h"
 #include "termpty.h"
 #include "termio.h"
 #include "termiointernals.h"
@@ -38,7 +38,7 @@ miniview_init(void)
 
    _miniview_log_dom = eina_log_domain_register("miniview", NULL);
    if (_miniview_log_dom < 0)
-     EINA_LOG_CRIT(_("Could not create logging domain '%s'."), "miniview");
+     EINA_LOG_CRIT(_("Could not create logging domain '%s'"), "miniview");
 }
 
 void
@@ -681,7 +681,8 @@ miniview_add(Evas_Object *parent, Evas_Object *termio)
    mv->termio = termio;
 
    mv->base = edje_object_add(canvas);
-   theme_apply(mv->base, termio_config_get(termio), "terminology/miniview");
+   theme_apply(mv->base, termio_config_get(termio), "terminology/miniview",
+               NULL, NULL, EINA_FALSE);
 
    evas_object_smart_member_add(mv->base, obj);
 
