@@ -203,6 +203,7 @@ struct _Termpty
    unsigned int mouse_ext  : 2;
    unsigned int bracketed_paste : 1;
    unsigned int decoding_error : 1;
+   unsigned int focus_reporting : 1;
    struct {
        Term_Link *links;
        uint8_t *bitmap;
@@ -281,7 +282,11 @@ void       termpty_config_update(Termpty *ty, Config *config);
 Termcell  *termpty_cellrow_get(Termpty *ty, int y, ssize_t *wret);
 Termcell * termpty_cell_get(Termpty *ty, int y_requested, int x_requested);
 ssize_t termpty_row_length(Termpty *ty, int y);
+
+#define TERMPTY_WRITE_STR(_S) \
+   termpty_write(ty, _S, strlen(_S))
 void       termpty_write(Termpty *ty, const char *input, int len);
+
 void       termpty_resize(Termpty *ty, int new_w, int new_h);
 void       termpty_resize_tabs(Termpty *ty, int old_w, int new_w);
 void       termpty_backscroll_adjust(Termpty *ty, int *scroll);
@@ -311,6 +316,8 @@ void term_link_free(Termpty *ty, Term_Link *link);
 int
 termpty_color_class_get(Termpty *ty, const char *key,
                         int *r, int *g, int *b, int *a);
+void
+termpty_focus_report(Termpty *ty, Eina_Bool focus);
 
 extern int _termpty_log_dom;
 
